<?php
/**
 * A general captcha
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class BaseCaptcha extends BaseHelper {
	/**
	 * A helper instance for the form
	 */
	private $helperInstance = null;

	/**
	 * Instance of an RNG
	 */
	private $rngInstance = null;

	/**
	 * Protected constructor
	 *
	 * @param	$className	Name of the class
	 * @return	void
	 */
	protected function __construct ($className) {
		// Call parent constructor
		parent::__construct($className);

		// Clean up a little
		$this->removeNumberFormaters();
		$this->removeSystemArray();
	}

	/**
	 * Initializes the random number generator (RNG)
	 *
	 * @param	$extraInstance	An extra instance, just for better hash data
	 * @return	void
	 */
	protected final function initializeRandomNumberGenerator (FrameworkInterface $extraInstance = null) {
		// Get an RNG from factory
		$this->rngInstance = ObjectFactory::createObjectByConfiguredName('rng_class', array($extraInstance));
	}

	/**
	 * Getter for RNG instance
	 *
	 * @return	$rngInstance	An instance of a random number generator (RNG)
	 */
	public final function getRngInstance () {
		return $this->rngInstance;
	}

	/**
	 * Setter for helper instance
	 *
	 * @param	$helperInstance		An instance of a helper class
	 * @return	void
	 */
	protected final function setHelperInstance (HelpableTemplate $helperInstance) {
		$this->helperInstance = $helperInstance;
	}

	/**
	 * Getter for helper instance
	 *
	 * @return	$helperInstance		An instance of a helper class
	 */
	public final function getHelperInstance () {
		return $this->helperInstance;
	}
}

// [EOF]
?>
