<?php
/**
 * This class simply puts text without any HTML code out. This class is suiable
 * for console output
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class ConsoleOutput extends BaseFrameworkSystem implements OutputStreamer {
	/**
	 * The instance for the singleton design pattern
	 */
	private static $consoleInstance = null;

	/**
	 * Assigned variables
	 */
	private $vars = array();

	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set description
		$this->setObjectDescription("Console output class");

		// Create an unique ID
		$this->generateUniqueId();
	}

	/**
	 * Create a new web output system and set the content type
	 *
	 * @param	$contentType	A valid content-type
	 * @return	$debugInstance	An instance of this middleware class
	 */
	public final static function createConsoleOutput ($contentType) {
		// Cast the content-type to string
		$contentType = (string) $contentType;
		$contentType = trim($contentType);

		// Get instance
		self::$consoleInstance = new ConsoleOutput();

		// Set the content type
		if (!empty($contentType)) {
			@header(sprintf("Content-type: %s",
				$contentType
			));
		}

		// Return instance
		return self::$consoleInstance;
	}

	/**
	 * Getter for an instance of this class
	 *
	 * @return	$consoleInstance	An instance of this class
	 */
	public final static function getInstance() {
		if (is_null(self::$consoleInstance)) {
			$contentType = FrameworkConfiguration::getInstance()->readConfig('web_content_type');
			self::$consoleInstance = ConsoleOutput::createConsoleOutput($contentType);
		}
		return self::$consoleInstance;
	}

	/**
	 * Output the code
	 *
	 * @param	$outStream	Something we shall sent to the console
	 * @return	void
	 */
	public final function output ($outStream=false) {
		if ($outStream === false) {
			// Output something here...
			foreach ($this->vars as $var=>$value) {
				$this->output("var=".$var.", value=".$value."");
			}
		} else {
			// Output it to the console
			printf("%s\n", trim(html_entity_decode(strip_tags($outStream))));
		}
	}

	/**
	 * Assigns a variable for output
	 *
	 * @param	$var	The variable we shall assign
	 * @param	$value	The value to store in the variable
	 * @return	void
	 */
	public function assignVariable ($var, $value) {
		$this->vars[$var] = $value;
	}
}

// [EOF]
?>
